### 0.13.2 {small}`2025-09-02`

```{rubric} Features
```
* adds support for sparse Truncated SVD in PCA {pr}`438` {smaller}`S Dicks`
* adds support for Truncated SVD in PCA with Dask arrays (sparse and dense) {pr}`438` {smaller}`S Dicks`
* enables out-of-core execution for dense Dask PCA with `svd_solver = 'covariance_eigh'` the new default {pr}`438` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* fixes a potential bug where unsorted CSR matrices could lead to instabilities {pr}`438` {smaller}`S Dicks`
* Fixes a small issue with `harmony` {pr}`444` {smaller}`S Dicks`

```{rubric} Misc
```
* All of `pp.harmony_integrate`'s run options are now tested against `harmonypy` {pr}`444` {smaller}`S Dicks`
